import { isRef, unref } from "vue";
import { buildRequestParams } from "./../helpers/index.js";
import { performRequest } from "./nuxtApp.js";
import { useAsyncData, useAppConfig, useNuxtApp } from "#imports";
import { hash } from "ohash";
export function useAsyncGraphqlQuery(name, ...args) {
  const variables = args[0];
  const asyncDataOptions = args[1] || {};
  const fetchOptions = asyncDataOptions.fetchOptions;
  const key = `graphql:${name}:${hash(unref(variables))}`;
  const config = useAppConfig();
  const app = useNuxtApp();
  if (import.meta.client) {
    if (variables && isRef(variables)) {
      if (!asyncDataOptions.watch) {
        asyncDataOptions.watch = [];
      }
      asyncDataOptions.watch.push(variables);
    }
    if (asyncDataOptions.graphqlCaching?.client && !asyncDataOptions.getCachedData) {
      asyncDataOptions.getCachedData = function(key2) {
        if (!app.isHydrating && !config.graphqlMiddleware.clientCacheEnabled) {
          return;
        }
        return app.payload.data[key2];
      };
    }
  }
  return useAsyncData(
    key,
    () => performRequest(
      "query",
      name,
      "get",
      {
        params: buildRequestParams(unref(variables)),
        ...fetchOptions
      },
      asyncDataOptions.graphqlCaching
    ),
    asyncDataOptions
  );
}
