import { createError } from "h3";
import { GraphqlMiddlewareOperation } from "./../../settings/index.js";
export function queryParamToVariables(query) {
  try {
    if (query.__variables && typeof query.__variables === "string") {
      return JSON.parse(query.__variables);
    }
  } catch (_e) {
  }
  return query;
}
export function getEndpoint(config, serverOptions, event, operation, operationName) {
  if (serverOptions.graphqlEndpoint) {
    const result = serverOptions.graphqlEndpoint(
      event,
      operation,
      operationName
    );
    if (result) {
      return Promise.resolve(result);
    }
  }
  if (config.graphqlEndpoint) {
    return config.graphqlEndpoint;
  }
  throw new Error("Failed to determine endpoint for GraphQL server.");
}
export function getFetchOptions(serverOptions, event, operation, operationName) {
  if (serverOptions.serverFetchOptions) {
    return serverOptions.serverFetchOptions(event, operation, operationName) || {};
  }
  return {};
}
export function throwError(statusMessage, statusCode = 400) {
  throw createError({
    statusCode,
    statusMessage
  });
}
export function validateRequest(method, operation, name, documents) {
  if (method !== "POST" && method !== "GET") {
    throwError("Method not allowed.", 405);
  }
  if (operation !== GraphqlMiddlewareOperation.Query && operation !== GraphqlMiddlewareOperation.Mutation) {
    throwError("Unknown operation.");
  }
  if (method === "POST" && operation !== GraphqlMiddlewareOperation.Mutation) {
    throwError("Queries must be a GET request.");
  }
  if (method === "GET" && operation !== GraphqlMiddlewareOperation.Query) {
    throwError("Mutations must be a POST request.");
  }
  if (!name) {
    throwError("Missing name for operation.");
  }
  if (!documents) {
    throwError("Failed to load GraphQL documents", 500);
  }
  if (!documents[operation][name]) {
    throwError(`Operation "${operation}" with name "${name}" not found.`);
  }
}
export function onServerResponse(serverOptions, event, response, operation, operationName) {
  if (serverOptions.onServerResponse) {
    return serverOptions.onServerResponse(
      event,
      response,
      operation,
      operationName
    );
  }
  return response._data;
}
export function onServerError(serverOptions, event, error, operation, operationName) {
  if (serverOptions.onServerError) {
    return serverOptions.onServerError(event, error, operation, operationName);
  }
  const message = error && "message" in error ? error.message : "";
  throw createError({
    statusCode: 500,
    statusMessage: "Couldn't execute GraphQL query: " + message,
    data: error && "message" in error ? error.message : error
  });
}
